@@ -58,8 +58,6 @@ import javax.xml.ws.Endpoint;
 import org.apache.commons.logging.Log;
 import org.apache.cxf.interceptor.DocLiteralInInterceptor;
 import org.apache.cxf.interceptor.Interceptor;
-import org.apache.cxf.interceptor.LoggingInInterceptor;
-import org.apache.cxf.interceptor.LoggingOutInterceptor;
 import org.apache.cxf.message.Message;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.InvalidSyntaxException;
@@ -213,23 +211,41 @@ public class WebserviceCollector implements ServiceListener {
             {
                 // Alter server's in-stream interceptors
                 final org.apache.cxf.endpoint.Endpoint serverEndpoint = (org.apache.cxf.endpoint.Endpoint) endpoint.getProperties();
-                final List<Interceptor<? extends Message>> inInterceptors = serverEndpoint.getBinding().getInInterceptors();
-                boolean found = false;
-                int index = 0;
-                for (final Interceptor<? extends Message> interceptor : inInterceptors) {
-                    if (interceptor instanceof DocLiteralInInterceptor) {
-                        found = true;
-                        break;
+                {
+                    final List<Interceptor<? extends Message>> inInterceptors = serverEndpoint.getBinding().getInInterceptors();
+                    boolean found = false;
+                    int index = 0;
+                    for (final Interceptor<? extends Message> interceptor : inInterceptors) {
+                        if (interceptor instanceof DocLiteralInInterceptor) {
+                            found = true;
+                            break;
+                        }
+                        index++;
+                    }
+                    if (found) {
+                        inInterceptors.remove(index);
+                        inInterceptors.add(index, new com.openexchange.soap.cxf.interceptor.DocLiteralInInterceptor());
                     }
-                    index++;
                 }
-                if (found) {
-                    inInterceptors.remove(index);
-                    inInterceptors.add(index, new com.openexchange.soap.cxf.interceptor.DocLiteralInInterceptor());
+                {
+                    final List<Interceptor<? extends Message>> inInterceptors = serverEndpoint.getBinding().getInInterceptors();
+                    boolean found = false;
+                    int index = 0;
+                    for (final Interceptor<? extends Message> interceptor : inInterceptors) {
+                        if (interceptor instanceof org.apache.cxf.binding.soap.interceptor.SoapActionInInterceptor) {
+                            found = true;
+                            break;
+                        }
+                        index++;
+                    }
+                    if (found) {
+                        inInterceptors.remove(index);
+                        inInterceptors.add(index, new com.openexchange.soap.cxf.interceptor.SoapActionInInterceptor());
+                    }
                 }
                 // Add logging interceptors
-                serverEndpoint.getInInterceptors().add(new LoggingInInterceptor());
-                serverEndpoint.getOutInterceptors().add(new LoggingOutInterceptor());
+                serverEndpoint.getInInterceptors().add(new com.openexchange.soap.cxf.interceptor.LoggingInInterceptor());
+                serverEndpoint.getOutInterceptors().add(new com.openexchange.soap.cxf.interceptor.LoggingOutInterceptor());
             }
             oldEndpoint = endpoints.replace(name, endpoint);
             LOG.info("Publishing endpoint succeeded. Published \"" + name + "\" under address \"" + address + "\".");
